==> icinga2_2.6.3.orig.tar.gz: icinga2-2.6.3/lib/icinga/checkresult.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "icinga/checkresult.hpp"
#include "icinga/checkresult.tcpp"
#include "base/scriptglobal.hpp"

using namespace icinga;

REGISTER_TYPE(CheckResult);
INITIALIZE_ONCE(&CheckResult::StaticInitialize);

void CheckResult::StaticInitialize(void)
{
	ScriptGlobal::Set("ServiceOK", ServiceOK);
	ScriptGlobal::Set("ServiceWarning", ServiceWarning);
	ScriptGlobal::Set("ServiceCritical", ServiceCritical);
	ScriptGlobal::Set("ServiceUnknown", ServiceUnknown);

	ScriptGlobal::Set("HostUp", HostUp);
	ScriptGlobal::Set("HostDown", HostDown);
}

double CheckResult::CalculateExecutionTime(void) const
{
	return GetExecutionEnd() - GetExecutionStart();
}

double CheckResult::CalculateLatency(void) const
{
	double latency = (GetScheduleEnd() - GetScheduleStart()) - CalculateExecutionTime();

	if (latency < 0)
		latency = 0;

	return latency;
}

==> icinga2-2.10.0.tar.gz: icinga2-2.10.0/lib/icinga/checkresult.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "icinga/checkresult.hpp"
#include "icinga/checkresult-ti.cpp"
#include "base/scriptglobal.hpp"

using namespace icinga;

REGISTER_TYPE(CheckResult);

INITIALIZE_ONCE([]() {
	ScriptGlobal::Set("Icinga.ServiceOK", ServiceOK, true);
	ScriptGlobal::Set("Icinga.ServiceWarning", ServiceWarning, true);
	ScriptGlobal::Set("Icinga.ServiceCritical", ServiceCritical, true);
	ScriptGlobal::Set("Icinga.ServiceUnknown", ServiceUnknown, true);

	ScriptGlobal::Set("Icinga.HostUp", HostUp, true);
	ScriptGlobal::Set("Icinga.HostDown", HostDown, true);
})

double CheckResult::CalculateExecutionTime() const
{
	return GetExecutionEnd() - GetExecutionStart();
}

double CheckResult::CalculateLatency() const
{
	double latency = (GetScheduleEnd() - GetScheduleStart()) - CalculateExecutionTime();

	if (latency < 0)
		latency = 0;

	return latency;
}
